"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const file_utils_1 = require("./file-utils");
const interface_definition_1 = require("./interface-definition");
const result_report_1 = require("./result-report");
class TypedGate {
    constructor(tsConfigFilePath, sourceFilePath) {
        this.tsConfigFilePath = tsConfigFilePath;
        this.sourceFilePath = sourceFilePath;
    }
    get validationResult() {
        return this._validationResult;
    }
    validateJsonFile(fileName) {
        return file_utils_1.loadJson(fileName).then(data => this.validateObject(data));
    }
    validateObject(targetData) {
        if (typeof targetData !== 'object' && targetData === null) {
            throw new Error('Root of provided JSON structure is not an object.');
        }
        const interfaceDefinition = new interface_definition_1.InterfaceDefinition({
            project: {
                tsConfigFilePath: this.tsConfigFilePath
            },
            sourceFilePath: this.sourceFilePath,
            targetData
        });
        const result = interfaceDefinition.compareToTarget();
        if (result.valid) {
            return true;
        }
        else {
            if (result.asts) {
                this._validationResult = new result_report_1.ResultReport(result.asts).generateReport();
            }
            return false;
        }
    }
}
exports.TypedGate = TypedGate;
//# sourceMappingURL=index.js.map